@@ -255,15 +255,18 @@ impl<T> Rotation3<T>
 where
     T: Float + NumCast + FloatConst,
 {
-    /// Returns any of transformations that rotate `-z`-axis to `dir`.
-    pub fn look_at_any(dir: Vector<T, 3>) -> Self {
+    /// Continuous version of `look_at_any`.
+    ///
+    /// It hasn't any discontinuities except single point `z = 1`.
+    fn look_at_any_cont(dir: Vector<T, 3>) -> Self {
         let z = Vector::from((T::zero(), T::zero(), -T::one()));
         let dot = z.dot(dir);
-        if T::one() + dot < T::epsilon() {
-            Self::new(
-                Vector::from((T::zero(), T::one(), T::zero())),
-                T::from(T::PI()).unwrap(),
-            )
+        if dot < T::zero() {
+            Self::look_at_any(-dir)
+            .chain(Self::new(
+                Vector::from((T::one(), T::zero(), T::zero())),
+                T::PI(),
+            ))
         } else {
             let cross = z.cross(dir);
             let cos = ((T::one() + dot) / T::from(2).unwrap()).sqrt();
@@ -271,6 +274,19 @@ where
             Self::from_quaternion((cos, cross * sin_mult).into())
         }
     }
+
+    /// Returns any of transformations that rotate `-z`-axis to `dir`.
+    pub fn look_at_any(dir: Vector<T, 3>) -> Self {
+        if dir.z() < T::zero() {
+            Self::look_at_any_cont(dir)
+        } else {
+            Self::look_at_any_cont(-dir)
+            .chain(Self::new(
+                Vector::from((T::one(), T::zero(), T::zero())),
+                T::PI(),
+            ))
+        }
+    }
 }
 
 impl<T> Reorder<Rotation2<T>, Vector<T, 2>> for Shift<T, 2>
